@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -69,15 +73,16 @@
 #define yylval          daslval
 #define yychar          daschar
 
-/* Copy the first part of user declarations.  */
-
-#line 75 "das.tab.cc" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -101,7 +106,7 @@
 extern int dasdebug;
 #endif
 /* "%code requires" blocks.  */
-#line 40 "das.yy" /* yacc.c:355  */
+#line 40 "das.yy" /* yacc.c:352  */
 
 
 #define YYSTYPE char *
@@ -146,7 +151,7 @@ using namespace libdap ;
 extern int das_line_num;	/* defined in das.lex */
 
 
-#line 150 "das.tab.cc" /* yacc.c:355  */
+#line 155 "das.tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -183,11 +188,9 @@ int dasparse (parser_arg *arg);
 
 #endif /* !YY_DAS_DAS_TAB_HH_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 189 "das.tab.cc" /* yacc.c:358  */
 /* Unqualified %code blocks.  */
-#line 85 "das.yy" /* yacc.c:359  */
+#line 85 "das.yy" /* yacc.c:355  */
 
 // No global static objects. We go through this every so often, I guess I
 // should learn... 1/24/2000 jhrg
@@ -227,7 +230,7 @@ static void add_bad_attribute(AttrTable *attr, const string &type,
 			      const string &msg);
 
 
-#line 231 "das.tab.cc" /* yacc.c:359  */
+#line 234 "das.tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -248,13 +251,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -266,7 +269,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -302,15 +305,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -318,7 +312,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -480,16 +474,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  134
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   270
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -733,22 +727,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (arg, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (arg, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -788,38 +782,38 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (arg);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, arg);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, arg);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -853,7 +847,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, parser_arg *arg)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -864,7 +858,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, parser_arg *ar
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , arg);
       YYFPRINTF (stderr, "\n");
     }
@@ -968,7 +962,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -986,7 +983,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1064,10 +1061,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1079,6 +1076,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1090,9 +1088,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1219,23 +1218,31 @@ yyparse (parser_arg *arg)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1251,14 +1258,10 @@ yyparse (parser_arg *arg)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1274,22 +1277,22 @@ yyparse (parser_arg *arg)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1298,11 +1301,11 @@ yyparse (parser_arg *arg)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1375,7 +1378,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1396,7 +1399,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 194 "das.yy" /* yacc.c:1661  */
+#line 194 "das.yy" /* yacc.c:1652  */
     {
 		if (!name) name = new string();
 		if (!type) type = new string();
@@ -1405,157 +1408,157 @@ yyreduce:
 		// push outermost AttrTable
 		PUSH(DAS_OBJ(arg)->get_top_level_attributes());
 	}
-#line 1409 "das.tab.cc" /* yacc.c:1661  */
+#line 1412 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 203 "das.yy" /* yacc.c:1661  */
+#line 203 "das.yy" /* yacc.c:1652  */
     {
 		POP;	// pop the DAS/AttrTable before stack's dtor
 		delete name; name = 0;
 		delete type; type = 0;
 		delete attr_tab_stack; attr_tab_stack = 0;
 	}
-#line 1420 "das.tab.cc" /* yacc.c:1661  */
+#line 1423 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 218 "das.yy" /* yacc.c:1661  */
+#line 218 "das.yy" /* yacc.c:1652  */
     {
 		    parse_error((parser_arg *)arg, NO_DAS_MSG, das_line_num);
 		}
-#line 1428 "das.tab.cc" /* yacc.c:1661  */
+#line 1431 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 230 "das.yy" /* yacc.c:1661  */
+#line 230 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "Byte", das_line_num); }
-#line 1434 "das.tab.cc" /* yacc.c:1661  */
+#line 1437 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 231 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1440 "das.tab.cc" /* yacc.c:1661  */
+#line 231 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1443 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 234 "das.yy" /* yacc.c:1661  */
+#line 234 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "Int16", das_line_num); }
-#line 1446 "das.tab.cc" /* yacc.c:1661  */
+#line 1449 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 235 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1452 "das.tab.cc" /* yacc.c:1661  */
+#line 235 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1455 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 238 "das.yy" /* yacc.c:1661  */
+#line 238 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "UInt16", das_line_num); }
-#line 1458 "das.tab.cc" /* yacc.c:1661  */
+#line 1461 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 239 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1464 "das.tab.cc" /* yacc.c:1661  */
+#line 239 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1467 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 242 "das.yy" /* yacc.c:1661  */
+#line 242 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "Int32", das_line_num); }
-#line 1470 "das.tab.cc" /* yacc.c:1661  */
+#line 1473 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 243 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1476 "das.tab.cc" /* yacc.c:1661  */
+#line 243 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1479 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 246 "das.yy" /* yacc.c:1661  */
+#line 246 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "UInt32", das_line_num); }
-#line 1482 "das.tab.cc" /* yacc.c:1661  */
+#line 1485 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 247 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1488 "das.tab.cc" /* yacc.c:1661  */
+#line 247 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1491 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 250 "das.yy" /* yacc.c:1661  */
+#line 250 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "Float32", das_line_num); }
-#line 1494 "das.tab.cc" /* yacc.c:1661  */
+#line 1497 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 251 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1500 "das.tab.cc" /* yacc.c:1661  */
+#line 251 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1503 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 30:
-#line 254 "das.yy" /* yacc.c:1661  */
+#line 254 "das.yy" /* yacc.c:1652  */
     { save_str(*type, "Float64", das_line_num); }
-#line 1506 "das.tab.cc" /* yacc.c:1661  */
+#line 1509 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 31:
-#line 255 "das.yy" /* yacc.c:1661  */
-    { save_str(*name, (yyvsp[0]), das_line_num); }
-#line 1512 "das.tab.cc" /* yacc.c:1661  */
+#line 255 "das.yy" /* yacc.c:1652  */
+    { save_str(*name, yyvsp[0], das_line_num); }
+#line 1515 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 33:
-#line 258 "das.yy" /* yacc.c:1661  */
+#line 258 "das.yy" /* yacc.c:1652  */
     { *type = "String"; }
-#line 1518 "das.tab.cc" /* yacc.c:1661  */
+#line 1521 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 34:
-#line 259 "das.yy" /* yacc.c:1661  */
-    { *name = (yyvsp[0]); }
-#line 1524 "das.tab.cc" /* yacc.c:1661  */
+#line 259 "das.yy" /* yacc.c:1652  */
+    { *name = yyvsp[0]; }
+#line 1527 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 36:
-#line 262 "das.yy" /* yacc.c:1661  */
+#line 262 "das.yy" /* yacc.c:1652  */
     { *type = "Url"; }
-#line 1530 "das.tab.cc" /* yacc.c:1661  */
+#line 1533 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 37:
-#line 263 "das.yy" /* yacc.c:1661  */
-    { *name = (yyvsp[0]); }
-#line 1536 "das.tab.cc" /* yacc.c:1661  */
+#line 263 "das.yy" /* yacc.c:1652  */
+    { *name = yyvsp[0]; }
+#line 1539 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 39:
-#line 266 "das.yy" /* yacc.c:1661  */
+#line 266 "das.yy" /* yacc.c:1652  */
     { *type = "OtherXML"; }
-#line 1542 "das.tab.cc" /* yacc.c:1661  */
+#line 1545 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 40:
-#line 267 "das.yy" /* yacc.c:1661  */
-    { *name = (yyvsp[0]); }
-#line 1548 "das.tab.cc" /* yacc.c:1661  */
+#line 267 "das.yy" /* yacc.c:1652  */
+    { *name = yyvsp[0]; }
+#line 1551 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 42:
-#line 271 "das.yy" /* yacc.c:1661  */
+#line 271 "das.yy" /* yacc.c:1652  */
     {
-		    DBG(cerr << "Processing ID: " << (yyvsp[0]) << endl);
+		    DBG(cerr << "Processing ID: " << yyvsp[0] << endl);
 		    
-		    AttrTable *at = TOP_OF_STACK->get_attr_table((yyvsp[0]));
+		    AttrTable *at = TOP_OF_STACK->get_attr_table(yyvsp[0]);
 		    if (!at) {
 			try {
-			    at = TOP_OF_STACK->append_container((yyvsp[0]));
+			    at = TOP_OF_STACK->append_container(yyvsp[0]);
 			}
 			catch (Error &e) {
 			    // re-throw with line number info
@@ -1568,208 +1571,208 @@ yyreduce:
 		    DBG(cerr << " Pushed attr_tab: " << at << endl);
 
 		}
-#line 1572 "das.tab.cc" /* yacc.c:1661  */
+#line 1575 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 43:
-#line 291 "das.yy" /* yacc.c:1661  */
+#line 291 "das.yy" /* yacc.c:1652  */
     {
 		    /* pop top of stack; store in attr_tab */
 		    DBG(cerr << " Popped attr_tab: " << TOP_OF_STACK << endl);
 		    POP;
 		}
-#line 1582 "das.tab.cc" /* yacc.c:1661  */
+#line 1585 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 45:
-#line 299 "das.yy" /* yacc.c:1661  */
+#line 299 "das.yy" /* yacc.c:1652  */
     { 
-		    parse_error(ATTR_TUPLE_MSG, das_line_num, (yyvsp[0]));
+		    parse_error(ATTR_TUPLE_MSG, das_line_num, yyvsp[0]);
 		}
-#line 1590 "das.tab.cc" /* yacc.c:1661  */
+#line 1593 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 47:
-#line 305 "das.yy" /* yacc.c:1661  */
+#line 305 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_byte);
+		    add_attribute(*type, *name, yyvsp[0], &check_byte);
 		}
-#line 1598 "das.tab.cc" /* yacc.c:1661  */
+#line 1601 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 48:
-#line 309 "das.yy" /* yacc.c:1661  */
+#line 309 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_byte);
+		    add_attribute(*type, *name, yyvsp[0], &check_byte);
 		}
-#line 1606 "das.tab.cc" /* yacc.c:1661  */
+#line 1609 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 49:
-#line 315 "das.yy" /* yacc.c:1661  */
+#line 315 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_int16);
+		    add_attribute(*type, *name, yyvsp[0], &check_int16);
 		}
-#line 1614 "das.tab.cc" /* yacc.c:1661  */
+#line 1617 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 50:
-#line 319 "das.yy" /* yacc.c:1661  */
+#line 319 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_int16);
+		    add_attribute(*type, *name, yyvsp[0], &check_int16);
 		}
-#line 1622 "das.tab.cc" /* yacc.c:1661  */
+#line 1625 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 51:
-#line 325 "das.yy" /* yacc.c:1661  */
+#line 325 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_uint16);
+		    add_attribute(*type, *name, yyvsp[0], &check_uint16);
 		}
-#line 1630 "das.tab.cc" /* yacc.c:1661  */
+#line 1633 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 52:
-#line 329 "das.yy" /* yacc.c:1661  */
+#line 329 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_uint16);
+		    add_attribute(*type, *name, yyvsp[0], &check_uint16);
 		}
-#line 1638 "das.tab.cc" /* yacc.c:1661  */
+#line 1641 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 53:
-#line 335 "das.yy" /* yacc.c:1661  */
+#line 335 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_int32);
+		    add_attribute(*type, *name, yyvsp[0], &check_int32);
 		}
-#line 1646 "das.tab.cc" /* yacc.c:1661  */
+#line 1649 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 54:
-#line 339 "das.yy" /* yacc.c:1661  */
+#line 339 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_int32);
+		    add_attribute(*type, *name, yyvsp[0], &check_int32);
 		}
-#line 1654 "das.tab.cc" /* yacc.c:1661  */
+#line 1657 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 55:
-#line 345 "das.yy" /* yacc.c:1661  */
+#line 345 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_uint32);
+		    add_attribute(*type, *name, yyvsp[0], &check_uint32);
 		}
-#line 1662 "das.tab.cc" /* yacc.c:1661  */
+#line 1665 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 56:
-#line 349 "das.yy" /* yacc.c:1661  */
+#line 349 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_uint32);
+		    add_attribute(*type, *name, yyvsp[0], &check_uint32);
 		}
-#line 1670 "das.tab.cc" /* yacc.c:1661  */
+#line 1673 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 57:
-#line 355 "das.yy" /* yacc.c:1661  */
+#line 355 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_float32);
+		    add_attribute(*type, *name, yyvsp[0], &check_float32);
 		}
-#line 1678 "das.tab.cc" /* yacc.c:1661  */
+#line 1681 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 58:
-#line 359 "das.yy" /* yacc.c:1661  */
+#line 359 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_float32);
+		    add_attribute(*type, *name, yyvsp[0], &check_float32);
 		}
-#line 1686 "das.tab.cc" /* yacc.c:1661  */
+#line 1689 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 59:
-#line 365 "das.yy" /* yacc.c:1661  */
+#line 365 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_float64);
+		    add_attribute(*type, *name, yyvsp[0], &check_float64);
 		}
-#line 1694 "das.tab.cc" /* yacc.c:1661  */
+#line 1697 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 60:
-#line 369 "das.yy" /* yacc.c:1661  */
+#line 369 "das.yy" /* yacc.c:1652  */
     {
-		    add_attribute(*type, *name, (yyvsp[0]), &check_float64);
+		    add_attribute(*type, *name, yyvsp[0], &check_float64);
 		}
-#line 1702 "das.tab.cc" /* yacc.c:1661  */
+#line 1705 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 61:
-#line 375 "das.yy" /* yacc.c:1661  */
+#line 375 "das.yy" /* yacc.c:1652  */
     {
-		    string attr = remove_quotes((yyvsp[0]));
+		    string attr = remove_quotes(yyvsp[0]);
 		    add_attribute(*type, *name, attr, 0);
 		}
-#line 1711 "das.tab.cc" /* yacc.c:1661  */
+#line 1714 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 62:
-#line 380 "das.yy" /* yacc.c:1661  */
+#line 380 "das.yy" /* yacc.c:1652  */
     {
-		    string attr = remove_quotes((yyvsp[0]));
+		    string attr = remove_quotes(yyvsp[0]);
 		    add_attribute(*type, *name, attr, 0);
 		}
-#line 1720 "das.tab.cc" /* yacc.c:1661  */
+#line 1723 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 63:
-#line 387 "das.yy" /* yacc.c:1661  */
+#line 387 "das.yy" /* yacc.c:1652  */
     {
-                    add_attribute(*type, *name, (yyvsp[0]), &check_url);
+                    add_attribute(*type, *name, yyvsp[0], &check_url);
                 }
-#line 1728 "das.tab.cc" /* yacc.c:1661  */
+#line 1731 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 64:
-#line 391 "das.yy" /* yacc.c:1661  */
+#line 391 "das.yy" /* yacc.c:1652  */
     {
-                    add_attribute(*type, *name, (yyvsp[0]), &check_url);
+                    add_attribute(*type, *name, yyvsp[0], &check_url);
                 }
-#line 1736 "das.tab.cc" /* yacc.c:1661  */
+#line 1739 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 65:
-#line 397 "das.yy" /* yacc.c:1661  */
+#line 397 "das.yy" /* yacc.c:1652  */
     {
                     // XML must be quoted in the DAS but the quotes are an
                     // artifact of the DAS syntax so they are not part of the
                     // value.
-                    string xml = unescape_double_quotes((yyvsp[0]));
+                    string xml = unescape_double_quotes(yyvsp[0]);
                     
                     if (is_quoted(xml))
                         add_attribute(*type, *name, remove_quotes(xml), 0);
                     else
                         add_attribute(*type, *name, xml, 0);
                 }
-#line 1752 "das.tab.cc" /* yacc.c:1661  */
+#line 1755 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 82:
-#line 425 "das.yy" /* yacc.c:1661  */
+#line 425 "das.yy" /* yacc.c:1652  */
     { 
-		    *name = (yyvsp[0]);
+		    *name = yyvsp[0];
 		}
-#line 1760 "das.tab.cc" /* yacc.c:1661  */
+#line 1763 "das.tab.cc" /* yacc.c:1652  */
     break;
 
   case 83:
-#line 429 "das.yy" /* yacc.c:1661  */
+#line 429 "das.yy" /* yacc.c:1652  */
     {
 		    add_alias( DAS_OBJ(arg)->get_top_level_attributes(),
-		               TOP_OF_STACK, *name, string((yyvsp[0])) ) ;
+		               TOP_OF_STACK, *name, string(yyvsp[0]) ) ;
                 }
-#line 1769 "das.tab.cc" /* yacc.c:1661  */
+#line 1772 "das.tab.cc" /* yacc.c:1652  */
     break;
 
 
-#line 1773 "das.tab.cc" /* yacc.c:1661  */
+#line 1776 "das.tab.cc" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1794,14 +1797,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1884,12 +1886,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1951,6 +1951,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1958,6 +1959,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1968,6 +1970,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1997,7 +2003,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 436 "das.yy" /* yacc.c:1906  */
+#line 436 "das.yy" /* yacc.c:1918  */
 
 
 // This function is required for linking, but DODS uses its own error
