@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -69,15 +73,16 @@
 #define yylval          ddslval
 #define yychar          ddschar
 
-/* Copy the first part of user declarations.  */
-
-#line 75 "dds.tab.cc" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -101,7 +106,7 @@
 extern int ddsdebug;
 #endif
 /* "%code requires" blocks.  */
-#line 47 "dds.yy" /* yacc.c:355  */
+#line 47 "dds.yy" /* yacc.c:352  */
 
 
 #include "config_dap.h"
@@ -147,7 +152,7 @@ using namespace libdap;
 extern int dds_line_num;	/* defined in dds.lex */
 
 
-#line 151 "dds.tab.cc" /* yacc.c:355  */
+#line 156 "dds.tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -178,12 +183,12 @@ extern int dds_line_num;	/* defined in dds.lex */
 
 union YYSTYPE
 {
-#line 131 "dds.yy" /* yacc.c:355  */
+#line 131 "dds.yy" /* yacc.c:352  */
 
     bool boolean;
     char word[ID_MAX];
 
-#line 187 "dds.tab.cc" /* yacc.c:355  */
+#line 192 "dds.tab.cc" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -198,11 +203,9 @@ int ddsparse (parser_arg *arg);
 
 #endif /* !YY_DDS_DDS_TAB_HH_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 204 "dds.tab.cc" /* yacc.c:358  */
 /* Unqualified %code blocks.  */
-#line 93 "dds.yy" /* yacc.c:359  */
+#line 93 "dds.yy" /* yacc.c:355  */
 
 
 // No global static objects in the dap library! 1/24/2000 jhrg
@@ -230,7 +233,7 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 			 char *type, char *name);
 
 
-#line 234 "dds.tab.cc" /* yacc.c:359  */
+#line 237 "dds.tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -251,13 +254,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -269,7 +272,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -305,15 +308,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -321,7 +315,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -483,16 +477,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  88
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   273
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -723,22 +717,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (arg, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (arg, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -778,38 +772,38 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (arg);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, arg);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, arg);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -843,7 +837,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, parser_arg *arg)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -854,7 +848,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, parser_arg *ar
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , arg);
       YYFPRINTF (stderr, "\n");
     }
@@ -958,7 +952,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -976,7 +973,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1054,10 +1051,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1069,6 +1066,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1080,9 +1078,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1209,23 +1208,31 @@ yyparse (parser_arg *arg)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1241,14 +1248,10 @@ yyparse (parser_arg *arg)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1264,22 +1267,22 @@ yyparse (parser_arg *arg)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1288,11 +1291,11 @@ yyparse (parser_arg *arg)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1365,7 +1368,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1386,7 +1389,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 160 "dds.yy" /* yacc.c:1661  */
+#line 160 "dds.yy" /* yacc.c:1652  */
     {
 		    /* On entry to the parser, make the BaseType stack. 
 		       I use if (!ctor) here because in the tab.cc file,
@@ -1397,57 +1400,57 @@ yyreduce:
 		    if (!ctor)
 		    	ctor = new stack<BaseType *>;
         }
-#line 1401 "dds.tab.cc" /* yacc.c:1661  */
+#line 1404 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 171 "dds.yy" /* yacc.c:1661  */
+#line 171 "dds.yy" /* yacc.c:1652  */
     {
 		    delete ctor; ctor = 0;
 		}
-#line 1409 "dds.tab.cc" /* yacc.c:1661  */
+#line 1412 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 181 "dds.yy" /* yacc.c:1661  */
+#line 181 "dds.yy" /* yacc.c:1652  */
     {
 		    (yyval.boolean) = (yyvsp[-3].boolean) && (yyvsp[-1].boolean);
 		}
-#line 1417 "dds.tab.cc" /* yacc.c:1661  */
+#line 1420 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 185 "dds.yy" /* yacc.c:1661  */
+#line 185 "dds.yy" /* yacc.c:1652  */
     {
 		    parse_error((parser_arg *)arg, NO_DDS_MSG, dds_line_num, (yyvsp[0].word));
 		    error_exit_cleanup();
 		    YYABORT;
 		}
-#line 1427 "dds.tab.cc" /* yacc.c:1661  */
+#line 1430 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 193 "dds.yy" /* yacc.c:1661  */
+#line 193 "dds.yy" /* yacc.c:1652  */
     {
 		    (yyval.boolean) = true;
 		}
-#line 1435 "dds.tab.cc" /* yacc.c:1661  */
+#line 1438 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 196 "dds.yy" /* yacc.c:1661  */
+#line 196 "dds.yy" /* yacc.c:1652  */
     { (yyval.boolean) = true; }
-#line 1441 "dds.tab.cc" /* yacc.c:1661  */
+#line 1444 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 197 "dds.yy" /* yacc.c:1661  */
+#line 197 "dds.yy" /* yacc.c:1652  */
     { (yyval.boolean) = true; }
-#line 1447 "dds.tab.cc" /* yacc.c:1661  */
+#line 1450 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 207 "dds.yy" /* yacc.c:1661  */
+#line 207 "dds.yy" /* yacc.c:1652  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1460,21 +1463,21 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1464 "dds.tab.cc" /* yacc.c:1661  */
+#line 1467 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 221 "dds.yy" /* yacc.c:1661  */
+#line 221 "dds.yy" /* yacc.c:1652  */
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1474 "dds.tab.cc" /* yacc.c:1661  */
+#line 1477 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 227 "dds.yy" /* yacc.c:1661  */
+#line 227 "dds.yy" /* yacc.c:1652  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1488,21 +1491,21 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1492 "dds.tab.cc" /* yacc.c:1661  */
+#line 1495 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 242 "dds.yy" /* yacc.c:1661  */
+#line 242 "dds.yy" /* yacc.c:1652  */
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1502 "dds.tab.cc" /* yacc.c:1661  */
+#line 1505 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 248 "dds.yy" /* yacc.c:1661  */
+#line 248 "dds.yy" /* yacc.c:1652  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1516,11 +1519,11 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1520 "dds.tab.cc" /* yacc.c:1661  */
+#line 1523 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 263 "dds.yy" /* yacc.c:1661  */
+#line 263 "dds.yy" /* yacc.c:1652  */
     { 
 		    if (is_keyword(string((yyvsp[-1].word)), "array")) {
 			    part = libdap::array;
@@ -1532,11 +1535,11 @@ yyreduce:
 			    YYABORT;
 		    }
         }
-#line 1536 "dds.tab.cc" /* yacc.c:1661  */
+#line 1539 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 275 "dds.yy" /* yacc.c:1661  */
+#line 275 "dds.yy" /* yacc.c:1652  */
     { 
 		    if (is_keyword(string((yyvsp[-1].word)), "maps")) {
 			    part = maps; 
@@ -1548,21 +1551,21 @@ yyreduce:
 			    YYABORT;
 		    }
         }
-#line 1552 "dds.tab.cc" /* yacc.c:1661  */
+#line 1555 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 287 "dds.yy" /* yacc.c:1661  */
+#line 287 "dds.yy" /* yacc.c:1652  */
     {
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1562 "dds.tab.cc" /* yacc.c:1661  */
+#line 1565 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 293 "dds.yy" /* yacc.c:1661  */
+#line 293 "dds.yy" /* yacc.c:1652  */
     {
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1577,106 +1580,106 @@ yyreduce:
         strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
         (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1581 "dds.tab.cc" /* yacc.c:1661  */
+#line 1584 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 309 "dds.yy" /* yacc.c:1661  */
+#line 309 "dds.yy" /* yacc.c:1652  */
     {
 		    ostringstream msg;
 		    msg << BAD_DECLARATION;
 		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1592 "dds.tab.cc" /* yacc.c:1661  */
+#line 1595 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 319 "dds.yy" /* yacc.c:1661  */
+#line 319 "dds.yy" /* yacc.c:1652  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
 		}
-#line 1600 "dds.tab.cc" /* yacc.c:1661  */
+#line 1603 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 325 "dds.yy" /* yacc.c:1661  */
+#line 325 "dds.yy" /* yacc.c:1652  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
 		}
-#line 1608 "dds.tab.cc" /* yacc.c:1661  */
+#line 1611 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 331 "dds.yy" /* yacc.c:1661  */
+#line 331 "dds.yy" /* yacc.c:1652  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
 		}
-#line 1616 "dds.tab.cc" /* yacc.c:1661  */
+#line 1619 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 336 "dds.yy" /* yacc.c:1661  */
+#line 336 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); }
-#line 1622 "dds.tab.cc" /* yacc.c:1661  */
+#line 1625 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 337 "dds.yy" /* yacc.c:1661  */
+#line 337 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); }
-#line 1628 "dds.tab.cc" /* yacc.c:1661  */
+#line 1631 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 338 "dds.yy" /* yacc.c:1661  */
+#line 338 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); }
-#line 1634 "dds.tab.cc" /* yacc.c:1661  */
+#line 1637 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 339 "dds.yy" /* yacc.c:1661  */
+#line 339 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); }
-#line 1640 "dds.tab.cc" /* yacc.c:1661  */
+#line 1643 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 340 "dds.yy" /* yacc.c:1661  */
+#line 340 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); }
-#line 1646 "dds.tab.cc" /* yacc.c:1661  */
+#line 1649 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 29:
-#line 341 "dds.yy" /* yacc.c:1661  */
+#line 341 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); }
-#line 1652 "dds.tab.cc" /* yacc.c:1661  */
+#line 1655 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 30:
-#line 342 "dds.yy" /* yacc.c:1661  */
+#line 342 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); }
-#line 1658 "dds.tab.cc" /* yacc.c:1661  */
+#line 1661 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 31:
-#line 343 "dds.yy" /* yacc.c:1661  */
+#line 343 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); }
-#line 1664 "dds.tab.cc" /* yacc.c:1661  */
+#line 1667 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 32:
-#line 344 "dds.yy" /* yacc.c:1661  */
+#line 344 "dds.yy" /* yacc.c:1652  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); }
-#line 1670 "dds.tab.cc" /* yacc.c:1661  */
+#line 1673 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 33:
-#line 347 "dds.yy" /* yacc.c:1661  */
+#line 347 "dds.yy" /* yacc.c:1652  */
     { current->set_name((yyvsp[0].word)); }
-#line 1676 "dds.tab.cc" /* yacc.c:1661  */
+#line 1679 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 49:
-#line 358 "dds.yy" /* yacc.c:1661  */
+#line 358 "dds.yy" /* yacc.c:1652  */
     { 
 		    if (!check_int32((yyvsp[-1].word))) {
 			    string msg = "In the dataset descriptor object:\n";
@@ -1696,19 +1699,19 @@ yyreduce:
 
 		    (yyval.boolean) = true;
 		 }
-#line 1700 "dds.tab.cc" /* yacc.c:1661  */
+#line 1703 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 50:
-#line 379 "dds.yy" /* yacc.c:1661  */
+#line 379 "dds.yy" /* yacc.c:1652  */
     {
 		     if (!id) id = new string((yyvsp[0].word));
 		 }
-#line 1708 "dds.tab.cc" /* yacc.c:1661  */
+#line 1711 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 51:
-#line 383 "dds.yy" /* yacc.c:1661  */
+#line 383 "dds.yy" /* yacc.c:1652  */
     { 
 		     if (!check_int32((yyvsp[0].word))) {
 			     string msg = "In the dataset descriptor object:\n";
@@ -1730,19 +1733,19 @@ yyreduce:
 
 		     delete id; id = 0;
 		 }
-#line 1734 "dds.tab.cc" /* yacc.c:1661  */
+#line 1737 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 52:
-#line 405 "dds.yy" /* yacc.c:1661  */
+#line 405 "dds.yy" /* yacc.c:1652  */
     {
 		     (yyval.boolean) = true;
 		 }
-#line 1742 "dds.tab.cc" /* yacc.c:1661  */
+#line 1745 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 53:
-#line 410 "dds.yy" /* yacc.c:1661  */
+#line 410 "dds.yy" /* yacc.c:1652  */
     {
 		     ostringstream msg;
 		     msg << "In the dataset descriptor object:" << endl
@@ -1750,23 +1753,23 @@ yyreduce:
 		     parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		     YYABORT;
 		 }
-#line 1754 "dds.tab.cc" /* yacc.c:1661  */
+#line 1757 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 54:
-#line 419 "dds.yy" /* yacc.c:1661  */
+#line 419 "dds.yy" /* yacc.c:1652  */
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true;}
-#line 1760 "dds.tab.cc" /* yacc.c:1661  */
+#line 1763 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 55:
-#line 420 "dds.yy" /* yacc.c:1661  */
+#line 420 "dds.yy" /* yacc.c:1652  */
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true; }
-#line 1766 "dds.tab.cc" /* yacc.c:1661  */
+#line 1769 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
   case 56:
-#line 422 "dds.yy" /* yacc.c:1661  */
+#line 422 "dds.yy" /* yacc.c:1652  */
     {
 		    ostringstream msg;
 		    msg << "Error parsing the dataset name." << endl
@@ -1774,11 +1777,11 @@ yyreduce:
 		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1778 "dds.tab.cc" /* yacc.c:1661  */
+#line 1781 "dds.tab.cc" /* yacc.c:1652  */
     break;
 
 
-#line 1782 "dds.tab.cc" /* yacc.c:1661  */
+#line 1785 "dds.tab.cc" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1803,14 +1806,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1893,12 +1895,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1960,6 +1960,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1967,6 +1968,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1977,6 +1979,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -2006,7 +2012,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 431 "dds.yy" /* yacc.c:1906  */
+#line 431 "dds.yy" /* yacc.c:1918  */
 
 
 /* 
