@@ -76,6 +76,13 @@ static void usage(const string &name)
 	cerr << "of a, d, or D are used with a URL, then the DAP library" << endl;
 	cerr << "routines are NOT used and the URLs contents are dumped" << endl;
 	cerr << "to standard output." << endl;
+	cerr << "Note: If the URL contains a query string the query string" << endl;
+	cerr << "will be preserved in the request. However, if the query " << endl;
+	cerr << "string contains DAP4 keys they may interfere with the" << endl;
+	cerr << "operation of " << name << ". A warning will be" << endl;
+	cerr << "written to stderr when "<< name << " identifies" << endl;
+	cerr << "the presence of a DAP4 query key in the submitted" << endl;
+	cerr << "URL's query string." << endl;
 	cerr << endl;
 	cerr << "In the second form of the command, assume the files are" << endl;
 	cerr << "DataDDS objects (stored in files or read from pipes)" << endl;
@@ -101,7 +108,6 @@ static void usage(const string &name)
 	cerr << "           NB: You can use a `?' for the CE also." << endl;
 }
 
-#if 1
 // Used for raw http access/transfer
 bool read_data(FILE * fp)
 {
@@ -112,13 +118,12 @@ bool read_data(FILE * fp)
     // Changed from a loop that used getc() to one that uses fread(). getc()
     // worked fine for transfers of text information, but *not* for binary
     // transfers. fread() will handle both.
-    char c;
+    char c = 0;
     while (fp && !feof(fp) && fread(&c, 1, 1, fp))
         printf("%c", c);        // stick with stdio
 
     return true;
 }
-#endif
 
 static void read_response_from_file(D4Connect *url, DMR &dmr, Response &r, bool mime_headers, bool get_dap4_data, bool get_dmr)
 {
@@ -140,17 +145,27 @@ static void read_response_from_file(D4Connect *url, DMR &dmr, Response &r, bool
     }
 }
 
+static void print_group_data(D4Group *g, bool print_rows = false)
+{
+    for (Constructor::Vars_iter i = g->var_begin(), e = g->var_end(); i != e; i++) {
+        if (print_rows && (*i)->type() == dods_sequence_c)
+            dynamic_cast<D4Sequence &>(**i).print_val_by_rows(cout);
+        else
+            (*i)->print_val(cout);
+    }
+
+    for (D4Group::groupsIter gi = g->grp_begin(), ge = g->grp_end(); gi != ge; ++gi) {
+        print_group_data(*gi, print_rows);
+    }
+}
+
 static void print_data(DMR &dmr, bool print_rows = false)
 {
     cout << "The data:" << endl;
 
     D4Group *g = dmr.root();
-    for (Constructor::Vars_iter i = g->var_begin(), e = g->var_end(); i != e; i++) {
-        if (print_rows && (*i)->type() == dods_sequence_c)
-            dynamic_cast < D4Sequence * >(*i)->print_val_by_rows(cout);
-        else
-            (*i)->print_val(cout);
-    }
+
+    print_group_data(g, print_rows);
 
     cout << endl << flush;
 }
@@ -231,7 +246,6 @@ int main(int argc, char *argv[])
         default:
             usage(argv[0]);
             exit(1);
-            break;
         }
 
     try {
@@ -243,7 +257,7 @@ int main(int argc, char *argv[])
 
             string name = argv[i];
             D4Connect *url = 0;
-
+            // auto_ptr? jhrg 10/19/15
             url = new D4Connect(name);
 
             // This overrides the value set in the .dodsrc file.
@@ -294,6 +308,8 @@ int main(int argc, char *argv[])
                 catch (Error & e) {
                     cerr << "Error: " << e.get_error_message() << endl;
                     delete url; url = 0;
+                    if (report_errors)
+                        return EXIT_FAILURE;
                 }
             }
             else if (get_dmr) {
@@ -340,6 +356,8 @@ int main(int argc, char *argv[])
                     }
                      catch (Error & e) {
                          cerr << e.get_error_message() << endl;
+                         if (report_errors)
+                             return EXIT_FAILURE;
                          continue;       // Goto the next URL or exit the loop.
                      }
                  }
@@ -370,6 +388,8 @@ int main(int argc, char *argv[])
                     }
                     catch (Error & e) {
                         cerr << e.get_error_message() << endl;
+                        if (report_errors)
+                            return EXIT_FAILURE;
                         continue;
                     }
                 }
@@ -387,13 +407,22 @@ int main(int argc, char *argv[])
         }
     }
     catch (Error &e) {
-        cerr << "Error: " << e.get_error_message() << endl;
-        cerr << "exiting" << endl;
+
+    	if(e.get_error_code() == malformed_expr){
+        	cerr << e.get_error_message() << endl;
+        	usage(argv[0]);
+    	}
+    	else {
+        	cerr << e.get_error_message() << endl;
+
+    	}
+
+        cerr << "Exiting." << endl;
         return 1;
     }
     catch (exception &e) {
         cerr << "C++ library exception: " << e.what() << endl;
-        cerr << "exiting" << endl;
+        cerr << "Exiting." << endl;
         return 1;
     }
 
