@@ -1,7 +1,7 @@
 #ifndef E_test_config_h
 #define E_test_config_h
 
-#define TEST_SRC_DIR "/home/ec2-user/hyrax/libdap4/unit-tests"
+#define TEST_SRC_DIR "/home/centos/hyrax/libdap4/unit-tests"
 
 #endif
 
